ApiCatalog
==========

.. currentmodule:: oda_api.data_products

.. autoclass:: ApiCatalog
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ApiCatalog.get_api_dictionary

   .. rubric:: Methods Documentation

   .. automethod:: get_api_dictionary
